@@ -12,7 +12,7 @@ AboutDialog::AboutDialog() : Gtk::AboutDialog()
     set_version(version);
     set_program_name("Horizon EDA");
     std::vector<Glib::ustring> authors;
-    authors.push_back("Lukas K. <horizon@0x83.eu>");
+    authors.push_back("Lukas K. <lukas@horizon-eda.org>");
     set_authors(authors);
     set_license_type(Gtk::LICENSE_GPL_3_0);
     set_copyright("Copyright © 2017-2019 Lukas K., et al.");
